{{- define "dnsmasq.conf" }}

keep-in-foreground
log-facility=/volume/log/dnsmasq/dnsmasq.log
# Will bind on all interfaces except lo, kube-ipvs and calico related.
# As long as we use only one configured interface per server it is pretty safe
except-interface=lo
except-interface=kube*
except-interface=cali*
except-interface=tunl*
bind-interfaces
dhcp-range={{- if .Values.dnsmasq.dhcp_range }}{{ .Values.dnsmasq.dhcp_range }}{{- else }}169.254.1.0,169.254.1.255{{- end }}
enable-tftp
tftp-root=/volume/tftpboot

# We provide stand-alone service, so lets
# Don't read the hostnames in /etc/hosts.
no-hosts
# And don't touch in-container resolvconf
no-poll
dhcp-leasefile=/volume/dnsmasq.leases
# Some extra logs might be good idea for debug..
log-dhcp
log-queries=extra

# This is one of the key options. dnsmasq tries to move out servername
# and PXE filename from special fields into DHCP options.
# Some old clients can't understand those DHCP options, so they
# will not be able to boot via PXE without this option enabled.
# For example gPXE will not work while iPXE works fine.
dhcp-no-override

# for many simultaneously DHCPDISCOVVER requests dnsmasq can offer
# the same IP for two differnt MAC addresses. This option prevents it
# by assigning IPs one by one instead of using hash algorithm.
dhcp-sequential-ip

dhcp-match=ipxe,175
# Client is already running iPXE; move to next stage of chainloading
#
# NOTE(sriazanov): dhcp-boot is used by ironic-operator for the reconciliation process
# All changes to it, should be aligned with ironic-operator logic
#
dhcp-boot=tag:ipxe,http://{{ .Values.httpd.service.loadBalancerIP }}:{{ .Values.ironic.configuration.http_port }}/dualboot.ipxe

# Note: Need to test EFI booting
dhcp-match=set:efi,option:client-arch,7
dhcp-match=set:efi,option:client-arch,9
dhcp-match=set:efi,option:client-arch,11
# Client is PXE booting over EFI without iPXE ROM; send EFI version of iPXE chainloader
dhcp-boot=tag:efi,tag:!ipxe,ipxe.efi

# Client is running PXE over BIOS; send BIOS version of iPXE chainloader
#
# NOTE(sriazanov): dhcp-boot is used by ironic-operator for the reconciliation process
# All changes to it, should be aligned with ironic-operator logic
#
dhcp-boot=/undionly.kpxe,{{ .Values.httpd.service.loadBalancerIP }}:{{ .Values.ironic.configuration.http_port }}

{{- range $opt := .Values.dnsmasq.dnsmasq_extra_opts }}
{{ $opt }}
{{- end }}
{{- end }}
