{{- define "ironic.conf" }}
[DEFAULT]
auth_strategy = noauth
host = 127.0.0.1
debug = false
log_dir = /volume/log/ironic
use_stderr = true
default_network_interface = noop
enabled_boot_interfaces = pxe,ipxe,fake
enabled_power_interfaces = ipmitool,idrac,fake
enabled_management_interfaces = ipmitool,idrac,fake
enabled_hardware_types = ipmi,idrac,fake-hardware
enabled_vendor_interfaces = ipmitool,no-vendor,idrac,fake
enabled_deploy_interfaces = direct,fake,ansible
default_boot_interface = ipxe
default_deploy_interface = direct
enabled_inspect_interfaces = inspector,idrac,fake
default_inspect_interface = inspector
rpc_transport = json-rpc
tempdir = /volume/log/ironic/tmp
[agent]
deploy_logs_collect = always
deploy_logs_local_path = /volume/log/ironic/deploy
[ansible]
playbooks_path=/volume/ansible/playbooks
config_file_path=/volume/ansible/playbooks/ansible.cfg
image_store_insecure=true
default_username=root
default_key_file=/volume/ansible/ansible_key
verbosity=3
[api]
api_workers = {{ .Values.ironic.configuration.api_workers }}
[audit]
[cimc]
[cinder]
[cisco_ucs]
[conductor]
inspect_wait_timeout = 0
enable_mdns = False
send_sensor_data = False
automated_clean = {{ .Values.ironic.configuration.automated_clean }}
#
# NOTE(sriazanov): api_url is used by ironic-operator for the reconciliation process
# All changes to it, should be aligned with ironic-operator logic
#
api_url = http://{{- if .Values.ironic.service.loadBalancerIP }}{{ .Values.ironic.service.loadBalancerIP }}{{- else }}127.0.0.1{{- end }}:6385
[console]
[cors]
[database]
connection = mysql+pymysql://ironic:{{- .Values.mariadb.password }}@mariadb-sql/ironic?charset=utf8
[deploy]
#
# NOTE(sriazanov): http_url is used by ironic-operator for the reconciliation process
# All changes to it, should be aligned with ironic-operator logic
#
http_url = http://{{ .Values.httpd.service.loadBalancerIP }}:{{ .Values.ironic.configuration.http_port }}
http_root = /volume/html/
default_boot_option = local
erase_devices_priority = 0
erase_devices_metadata_priority = 10
[dhcp]
dhcp_provider = none
[disk_partitioner]
[disk_utils]
[drac]
[glance]
[healthcheck]
[ilo]
[inspector]
endpoint_override = http://ironic-inspector-api-http:5050
[ipmi]
[irmc]
[ironic_lib]
[iscsi]
[json_rpc]
host_ip = 0.0.0.0
port = 8089
[keystone_authtoken]
[mdns]
[metrics]
[metrics_statsd]
[neutron]
[oslo_concurrency]
[oslo_messaging_amqp]
[oslo_messaging_kafka]
[oslo_messaging_notifications]
driver = prometheus_exporter
transport_url = fake://
location = /tmp/ironic_prometheus_exporter
[oslo_messaging_rabbit]
[oslo_policy]
[profiler]
[pxe]
ipxe_enabled = true
tftp_root = /volume/tftpboot
tftp_master_path = /volume/tftpboot
instance_master_path = /volume/html/master_images
images_path = /volume/html/tmp
pxe_config_template = $pybasedir/drivers/modules/ipxe_config.template
uefi_pxe_config_template = $pybasedir/drivers/modules/ipxe_config.template
#
# NOTE(sriazanov): pxe_append_params is used by ironic-operator for the reconciliation process
# All changes to it, should be aligned with ironic-operator logic
#
pxe_append_params = sshkey_url="http://{{ .Values.httpd.service.loadBalancerIP }}:{{ .Values.ironic.configuration.http_port }}/ansible_key.pub"
[service_catalog]
[snmp]
[ssl]
[swift]
[xclarity]
{{- end }}
